
// --------------------------------------------------------------------------------------------------------------
// Shader.vsh - Copyright (c) 2013 Markus Röder (wheemedia). All rights reserved.
// --------------------------------------------------------------------------------------------------------------

precision highp float;

uniform mat4 modelviewprojectionmatrix;
uniform mat4 modelmatrix;
uniform mat3 normalmatrix;
uniform vec4 diffusecolor;
uniform vec4 fogset;

attribute vec4 position;
attribute vec3 normal;
attribute vec2 texcoord;

varying vec4 interpolated_color;        // lowp
varying vec2 interpolated_texcoord;     // lowp

void main()
{
	if (normal.x==0.0 && normal.y==0.0 && normal.z==0.0) {

        // transform
        gl_Position = modelviewprojectionmatrix * position;                 // gl_Position = projectionmatrix * modelmatrix * viewmatrix * position;

		// no normal, no light, just color
		interpolated_color = diffusecolor;
        interpolated_texcoord = texcoord;
        
	}
	else {
        
        // transform
        gl_Position = modelviewprojectionmatrix * position;                 // gl_Position = projectionmatrix * viewmatrix * modelmatrix * position;
		
        // calc light
	    vec3 eyenormal = normalize(normalmatrix * normal);
    	vec3 lightposition = vec3(0.0, 0.0, 1.0);
        float lightmul = min(1.0, dot(eyenormal, lightposition));           // [0.00,1.00]
        lightmul = 0.6+lightmul*0.4;                                       // [0.5,0.75]
        
        // calc height
        vec4 wsp = modelmatrix * position;
        float heightmul = 1.0 + wsp.z * 0.5;                                // [1.00,~1.50]
        
        // calc fog
        float fogmul = (fogset.y-gl_Position.z)/(fogset.y-fogset.x);        // [0.00,~1.00]

        // set
		interpolated_color.rgb = diffusecolor.rgb * (lightmul * heightmul * fogmul) ;
        interpolated_color.a = diffusecolor.a;
        interpolated_texcoord = texcoord;
        
	}
}
